2017.3.16
=========

* Add support to new Django 1.10 Middleware
* refactoring test suite
* Supporting Universal Wheels, eggs and cheese.


2016.5.29
=========

* Drop Python 3.2, Python 3.3 capability.
* Support Django +1.8 version only.
* Fix: Test runner and tests with newer syntax and Django versions.



2014.9.28
=========
----

* Fix #11: Import fails in Django 1.7.
* Feature: Running test suite with travis on multiple Django versions.
* Feature: Code cleanup and pep8.
* Feature: Add ``Tests`` section to ``README.rst``.
* Feature: Add ``Supported Python versions``section to ``README.rst``.


2014.9.19
=========
----

* Fix getting custom user model.
* Django > 1.5 < 1.7 support.
* Feature #8: Add Python 3 support.
* Fix #9: Django 1.7 compatibility for test suite.
* Feature: Add pypy support.


2014.6.21
=========
----

* Add changelog.rst file.
* Add manifest.in file.
* Add license file.
* Run the test out of django-admin.py.
* Remove license header from files.
* Add travis-ci testing ;).
* Fix to make it compatible with django >= 1.5.
* Add ability to specify user class
